/*******************************************************************************
* File: main.c
*
* Version: 1.0
*
* Description:
*  Cet exemple montre la gestion de l'alimentation du PSoC4
*  Le mode hibernation est activée au bout de 8 s.
*  La désactivation de ce mode se fait en appuyant sur le possoir SW2
*  Pendant l'activation les couleurs de la LED sont allumées successivement
*
*******************************************************************************/
#include <device.h>
#include <cyPm.h>

#define STOP 		0
#define RUN 		1
#define HIBERNATE 	2

#define BLACK		0
#define RED			1
#define GREEN		2
#define YELLOW		3
#define BLUE		4
#define MAGENTA		5
#define CYAN		6
#define WHITE		7


/* Prototype de fonction */
void FlashRGB(uint8 Color, uint16 Period, uint16 Number);


CY_ISR(isr_wakeup)
{
	P0_7_ClearInterrupt();
    CyDelay(100);
}
 

void main()
{
    uint32 CauseReset;
	uint8 C;
	
    /* Dégeler les entrée / sorties */
    CySysPmUnfreezeIo();


    /* Config. ISR */
    CyIntSetVector(0, isr_wakeup);
    CyIntDisable(0);
    
    /* Détermine la cause du reset */
    CauseReset = CySysPmGetResetReason();
	
    switch (CauseReset)
    {
        case CY_PM_RESET_REASON_WAKEUP_STOP:
            FlashRGB(RED,200,8);
            break;
        case CY_PM_RESET_REASON_WAKEUP_HIB:
            FlashRGB(GREEN,200,8);
            break;
        case CY_PM_RESET_REASON_XRES:
            FlashRGB(BLUE,200,8);
            break;
        default:
           FlashRGB(WHITE,200,8);
    }

    /* Enabling global interrupts. */
    CyGlobalIntEnable;

    while(1)
    {
   		if (C<7) C++;
		else C=0;
		CyDelay(1000);
		RGB_Write(C );
		if (P0_7_Read()==0)
		{
			CyDelay(100);
			while(P0_7_Read()==0);
			CyIntEnable(0);
			RGB_Write(RED);
			CySysPmFreezeIo();
        	CySysPmStop();
		}
 
       
    }
}

/* Corps des Fonctions */
void FlashRGB(uint8 Color, uint16 Period, uint16 Number)
{
	uint16 I;
	for(I=0;I<Number;I++)
	{
		RGB_Write(Color);
		CyDelay(Period/2);
		RGB_Write(BLACK);
		CyDelay(Period/2);
	}
}

/* [] END OF FILE */
